@@ -19,6 +19,10 @@ from typing import Dict, Type
 from .base import AutoSuggestionServiceTransport
 from .grpc import AutoSuggestionServiceGrpcTransport
 from .grpc_asyncio import AutoSuggestionServiceGrpcAsyncIOTransport
+from .rest import (
+    AutoSuggestionServiceRestInterceptor,
+    AutoSuggestionServiceRestTransport,
+)
 
 # Compile a registry of transports.
 _transport_registry = (
@@ -26,9 +30,12 @@ _transport_registry = (
 )  # type: Dict[str, Type[AutoSuggestionServiceTransport]]
 _transport_registry["grpc"] = AutoSuggestionServiceGrpcTransport
 _transport_registry["grpc_asyncio"] = AutoSuggestionServiceGrpcAsyncIOTransport
+_transport_registry["rest"] = AutoSuggestionServiceRestTransport
 
 __all__ = (
     "AutoSuggestionServiceTransport",
     "AutoSuggestionServiceGrpcTransport",
     "AutoSuggestionServiceGrpcAsyncIOTransport",
+    "AutoSuggestionServiceRestTransport",
+    "AutoSuggestionServiceRestInterceptor",
 )
