@@ -16,7 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
+from typing import (
+    Dict,
+    Mapping,
+    MutableMapping,
+    MutableSequence,
+    Optional,
+    Sequence,
+    Tuple,
+    Type,
+    Union,
+    cast,
+)
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
@@ -27,7 +38,8 @@ from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
-import pkg_resources
+
+from google.cloud.dataqna_v1alpha import gapic_version as package_version
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -67,7 +79,7 @@ class QuestionServiceClientMeta(type):
 
     def get_transport_class(
         cls,
-        label: str = None,
+        label: Optional[str] = None,
     ) -> Type[QuestionServiceTransport]:
         """Returns an appropriate transport class.
 
@@ -381,8 +393,8 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         self,
         *,
         credentials: Optional[ga_credentials.Credentials] = None,
-        transport: Union[str, QuestionServiceTransport, None] = None,
-        client_options: Optional[client_options_lib.ClientOptions] = None,
+        transport: Optional[Union[str, QuestionServiceTransport]] = None,
+        client_options: Optional[Union[client_options_lib.ClientOptions, dict]] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
         """Instantiates the question service client.
@@ -399,7 +411,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
                 NOTE: "rest" transport functionality is currently in a
                 beta state (preview). We welcome your feedback via an
                 issue in this library's source repository.
-            client_options (google.api_core.client_options.ClientOptions): Custom options for the
+            client_options (Optional[Union[google.api_core.client_options.ClientOptions, dict]]): Custom options for the
                 client. It won't take effect if a ``transport`` instance is provided.
                 (1) The ``api_endpoint`` property can be used to override the
                 default endpoint provided by the client. GOOGLE_API_USE_MTLS_ENDPOINT
@@ -429,6 +441,7 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
             client_options = client_options_lib.from_dict(client_options)
         if client_options is None:
             client_options = client_options_lib.ClientOptions()
+        client_options = cast(client_options_lib.ClientOptions, client_options)
 
         api_endpoint, client_cert_source_func = self.get_mtls_endpoint_and_cert_source(
             client_options
@@ -481,11 +494,11 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def get_question(
         self,
-        request: Union[question_service.GetQuestionRequest, dict] = None,
+        request: Optional[Union[question_service.GetQuestionRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> question.Question:
         r"""Gets a previously created question.
@@ -586,12 +599,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def create_question(
         self,
-        request: Union[question_service.CreateQuestionRequest, dict] = None,
+        request: Optional[Union[question_service.CreateQuestionRequest, dict]] = None,
         *,
-        parent: str = None,
-        question: gcd_question.Question = None,
+        parent: Optional[str] = None,
+        question: Optional[gcd_question.Question] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcd_question.Question:
         r"""Creates a question.
@@ -705,12 +718,12 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def execute_question(
         self,
-        request: Union[question_service.ExecuteQuestionRequest, dict] = None,
+        request: Optional[Union[question_service.ExecuteQuestionRequest, dict]] = None,
         *,
-        name: str = None,
-        interpretation_index: int = None,
+        name: Optional[str] = None,
+        interpretation_index: Optional[int] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> question.Question:
         r"""Executes an interpretation.
@@ -821,11 +834,11 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def get_user_feedback(
         self,
-        request: Union[question_service.GetUserFeedbackRequest, dict] = None,
+        request: Optional[Union[question_service.GetUserFeedbackRequest, dict]] = None,
         *,
-        name: str = None,
+        name: Optional[str] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> user_feedback.UserFeedback:
         r"""Gets previously created user feedback.
@@ -922,12 +935,14 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
 
     def update_user_feedback(
         self,
-        request: Union[question_service.UpdateUserFeedbackRequest, dict] = None,
+        request: Optional[
+            Union[question_service.UpdateUserFeedbackRequest, dict]
+        ] = None,
         *,
-        user_feedback: gcd_user_feedback.UserFeedback = None,
-        update_mask: field_mask_pb2.FieldMask = None,
+        user_feedback: Optional[gcd_user_feedback.UserFeedback] = None,
+        update_mask: Optional[field_mask_pb2.FieldMask] = None,
         retry: OptionalRetry = gapic_v1.method.DEFAULT,
-        timeout: float = None,
+        timeout: Union[float, object] = gapic_v1.method.DEFAULT,
         metadata: Sequence[Tuple[str, str]] = (),
     ) -> gcd_user_feedback.UserFeedback:
         r"""Updates user feedback. This creates user feedback if
@@ -1051,14 +1066,9 @@ class QuestionServiceClient(metaclass=QuestionServiceClientMeta):
         self.transport.close()
 
 
-try:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
-        gapic_version=pkg_resources.get_distribution(
-            "google-cloud-dataqna",
-        ).version,
-    )
-except pkg_resources.DistributionNotFound:
-    DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo()
+DEFAULT_CLIENT_INFO = gapic_v1.client_info.ClientInfo(
+    gapic_version=package_version.__version__
+)
 
 
 __all__ = ("QuestionServiceClient",)
