@@ -18,10 +18,12 @@ import os
 # try/except added for compatibility with python < 3.8
 try:
     from unittest import mock
-    from unittest.mock import AsyncMock
-except ImportError:
+    from unittest.mock import AsyncMock  # pragma: NO COVER
+except ImportError:  # pragma: NO COVER
     import mock
 
+from collections.abc import Iterable
+import json
 import math
 
 from google.api_core import gapic_v1, grpc_helpers, grpc_helpers_async, path_template
@@ -31,10 +33,14 @@ import google.auth
 from google.auth import credentials as ga_credentials
 from google.auth.exceptions import MutualTLSChannelError
 from google.oauth2 import service_account
+from google.protobuf import json_format
 import grpc
 from grpc.experimental import aio
+from proto.marshal.rules import wrappers
 from proto.marshal.rules.dates import DurationRule, TimestampRule
 import pytest
+from requests import PreparedRequest, Request, Response
+from requests.sessions import Session
 
 from google.cloud.dataqna_v1alpha.services.auto_suggestion_service import (
     AutoSuggestionServiceAsyncClient,
@@ -94,6 +100,7 @@ def test__get_default_mtls_endpoint():
     [
         (AutoSuggestionServiceClient, "grpc"),
         (AutoSuggestionServiceAsyncClient, "grpc_asyncio"),
+        (AutoSuggestionServiceClient, "rest"),
     ],
 )
 def test_auto_suggestion_service_client_from_service_account_info(
@@ -109,7 +116,11 @@ def test_auto_suggestion_service_client_from_service_account_info(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("dataqna.googleapis.com:443")
+        assert client.transport._host == (
+            "dataqna.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://dataqna.googleapis.com"
+        )
 
 
 @pytest.mark.parametrize(
@@ -117,6 +128,7 @@ def test_auto_suggestion_service_client_from_service_account_info(
     [
         (transports.AutoSuggestionServiceGrpcTransport, "grpc"),
         (transports.AutoSuggestionServiceGrpcAsyncIOTransport, "grpc_asyncio"),
+        (transports.AutoSuggestionServiceRestTransport, "rest"),
     ],
 )
 def test_auto_suggestion_service_client_service_account_always_use_jwt(
@@ -142,6 +154,7 @@ def test_auto_suggestion_service_client_service_account_always_use_jwt(
     [
         (AutoSuggestionServiceClient, "grpc"),
         (AutoSuggestionServiceAsyncClient, "grpc_asyncio"),
+        (AutoSuggestionServiceClient, "rest"),
     ],
 )
 def test_auto_suggestion_service_client_from_service_account_file(
@@ -164,13 +177,18 @@ def test_auto_suggestion_service_client_from_service_account_file(
         assert client.transport._credentials == creds
         assert isinstance(client, client_class)
 
-        assert client.transport._host == ("dataqna.googleapis.com:443")
+        assert client.transport._host == (
+            "dataqna.googleapis.com:443"
+            if transport_name in ["grpc", "grpc_asyncio"]
+            else "https://dataqna.googleapis.com"
+        )
 
 
 def test_auto_suggestion_service_client_get_transport_class():
     transport = AutoSuggestionServiceClient.get_transport_class()
     available_transports = [
         transports.AutoSuggestionServiceGrpcTransport,
+        transports.AutoSuggestionServiceRestTransport,
     ]
     assert transport in available_transports
 
@@ -191,6 +209,11 @@ def test_auto_suggestion_service_client_get_transport_class():
             transports.AutoSuggestionServiceGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (
+            AutoSuggestionServiceClient,
+            transports.AutoSuggestionServiceRestTransport,
+            "rest",
+        ),
     ],
 )
 @mock.patch.object(
@@ -346,6 +369,18 @@ def test_auto_suggestion_service_client_client_options(
             "grpc_asyncio",
             "false",
         ),
+        (
+            AutoSuggestionServiceClient,
+            transports.AutoSuggestionServiceRestTransport,
+            "rest",
+            "true",
+        ),
+        (
+            AutoSuggestionServiceClient,
+            transports.AutoSuggestionServiceRestTransport,
+            "rest",
+            "false",
+        ),
     ],
 )
 @mock.patch.object(
@@ -549,6 +584,11 @@ def test_auto_suggestion_service_client_get_mtls_endpoint_and_cert_source(client
             transports.AutoSuggestionServiceGrpcAsyncIOTransport,
             "grpc_asyncio",
         ),
+        (
+            AutoSuggestionServiceClient,
+            transports.AutoSuggestionServiceRestTransport,
+            "rest",
+        ),
     ],
 )
 def test_auto_suggestion_service_client_client_options_scopes(
@@ -589,6 +629,12 @@ def test_auto_suggestion_service_client_client_options_scopes(
             "grpc_asyncio",
             grpc_helpers_async,
         ),
+        (
+            AutoSuggestionServiceClient,
+            transports.AutoSuggestionServiceRestTransport,
+            "rest",
+            None,
+        ),
     ],
 )
 def test_auto_suggestion_service_client_client_options_credentials_file(
@@ -846,6 +892,222 @@ async def test_suggest_queries_field_headers_async():
     ) in kw["metadata"]
 
 
+@pytest.mark.parametrize(
+    "request_type",
+    [
+        auto_suggestion_service.SuggestQueriesRequest,
+        dict,
+    ],
+)
+def test_suggest_queries_rest(request_type):
+    client = AutoSuggestionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "projects/sample1/locations/sample2"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(type(client.transport._session), "request") as req:
+        # Designate an appropriate value for the returned response.
+        return_value = auto_suggestion_service.SuggestQueriesResponse()
+
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 200
+        pb_return_value = auto_suggestion_service.SuggestQueriesResponse.pb(
+            return_value
+        )
+        json_return_value = json_format.MessageToJson(pb_return_value)
+
+        response_value._content = json_return_value.encode("UTF-8")
+        req.return_value = response_value
+        response = client.suggest_queries(request)
+
+    # Establish that the response is the type that we expect.
+    assert isinstance(response, auto_suggestion_service.SuggestQueriesResponse)
+
+
+def test_suggest_queries_rest_required_fields(
+    request_type=auto_suggestion_service.SuggestQueriesRequest,
+):
+    transport_class = transports.AutoSuggestionServiceRestTransport
+
+    request_init = {}
+    request_init["parent"] = ""
+    request = request_type(**request_init)
+    pb_request = request_type.pb(request)
+    jsonified_request = json.loads(
+        json_format.MessageToJson(
+            pb_request,
+            including_default_value_fields=False,
+            use_integers_for_enums=False,
+        )
+    )
+
+    # verify fields with default values are dropped
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).suggest_queries._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with default values are now present
+
+    jsonified_request["parent"] = "parent_value"
+
+    unset_fields = transport_class(
+        credentials=ga_credentials.AnonymousCredentials()
+    ).suggest_queries._get_unset_required_fields(jsonified_request)
+    jsonified_request.update(unset_fields)
+
+    # verify required fields with non-default values are left alone
+    assert "parent" in jsonified_request
+    assert jsonified_request["parent"] == "parent_value"
+
+    client = AutoSuggestionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport="rest",
+    )
+    request = request_type(**request_init)
+
+    # Designate an appropriate value for the returned response.
+    return_value = auto_suggestion_service.SuggestQueriesResponse()
+    # Mock the http request call within the method and fake a response.
+    with mock.patch.object(Session, "request") as req:
+        # We need to mock transcode() because providing default values
+        # for required fields will fail the real version if the http_options
+        # expect actual values for those fields.
+        with mock.patch.object(path_template, "transcode") as transcode:
+            # A uri without fields and an empty body will force all the
+            # request fields to show up in the query_params.
+            pb_request = request_type.pb(request)
+            transcode_result = {
+                "uri": "v1/sample_method",
+                "method": "post",
+                "query_params": pb_request,
+            }
+            transcode_result["body"] = pb_request
+            transcode.return_value = transcode_result
+
+            response_value = Response()
+            response_value.status_code = 200
+
+            pb_return_value = auto_suggestion_service.SuggestQueriesResponse.pb(
+                return_value
+            )
+            json_return_value = json_format.MessageToJson(pb_return_value)
+
+            response_value._content = json_return_value.encode("UTF-8")
+            req.return_value = response_value
+
+            response = client.suggest_queries(request)
+
+            expected_params = []
+            actual_params = req.call_args.kwargs["params"]
+            assert expected_params == actual_params
+
+
+def test_suggest_queries_rest_unset_required_fields():
+    transport = transports.AutoSuggestionServiceRestTransport(
+        credentials=ga_credentials.AnonymousCredentials
+    )
+
+    unset_fields = transport.suggest_queries._get_unset_required_fields({})
+    assert set(unset_fields) == (set(()) & set(("parent",)))
+
+
+@pytest.mark.parametrize("null_interceptor", [True, False])
+def test_suggest_queries_rest_interceptors(null_interceptor):
+    transport = transports.AutoSuggestionServiceRestTransport(
+        credentials=ga_credentials.AnonymousCredentials(),
+        interceptor=None
+        if null_interceptor
+        else transports.AutoSuggestionServiceRestInterceptor(),
+    )
+    client = AutoSuggestionServiceClient(transport=transport)
+    with mock.patch.object(
+        type(client.transport._session), "request"
+    ) as req, mock.patch.object(
+        path_template, "transcode"
+    ) as transcode, mock.patch.object(
+        transports.AutoSuggestionServiceRestInterceptor, "post_suggest_queries"
+    ) as post, mock.patch.object(
+        transports.AutoSuggestionServiceRestInterceptor, "pre_suggest_queries"
+    ) as pre:
+        pre.assert_not_called()
+        post.assert_not_called()
+        pb_message = auto_suggestion_service.SuggestQueriesRequest.pb(
+            auto_suggestion_service.SuggestQueriesRequest()
+        )
+        transcode.return_value = {
+            "method": "post",
+            "uri": "my_uri",
+            "body": pb_message,
+            "query_params": pb_message,
+        }
+
+        req.return_value = Response()
+        req.return_value.status_code = 200
+        req.return_value.request = PreparedRequest()
+        req.return_value._content = (
+            auto_suggestion_service.SuggestQueriesResponse.to_json(
+                auto_suggestion_service.SuggestQueriesResponse()
+            )
+        )
+
+        request = auto_suggestion_service.SuggestQueriesRequest()
+        metadata = [
+            ("key", "val"),
+            ("cephalopod", "squid"),
+        ]
+        pre.return_value = request, metadata
+        post.return_value = auto_suggestion_service.SuggestQueriesResponse()
+
+        client.suggest_queries(
+            request,
+            metadata=[
+                ("key", "val"),
+                ("cephalopod", "squid"),
+            ],
+        )
+
+        pre.assert_called_once()
+        post.assert_called_once()
+
+
+def test_suggest_queries_rest_bad_request(
+    transport: str = "rest", request_type=auto_suggestion_service.SuggestQueriesRequest
+):
+    client = AutoSuggestionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(),
+        transport=transport,
+    )
+
+    # send a request that will satisfy transcoding
+    request_init = {"parent": "projects/sample1/locations/sample2"}
+    request = request_type(**request_init)
+
+    # Mock the http request call within the method and fake a BadRequest error.
+    with mock.patch.object(Session, "request") as req, pytest.raises(
+        core_exceptions.BadRequest
+    ):
+        # Wrap the value into a proper Response obj
+        response_value = Response()
+        response_value.status_code = 400
+        response_value.request = Request()
+        req.return_value = response_value
+        client.suggest_queries(request)
+
+
+def test_suggest_queries_rest_error():
+    client = AutoSuggestionServiceClient(
+        credentials=ga_credentials.AnonymousCredentials(), transport="rest"
+    )
+
+
 def test_credentials_transport_error():
     # It is an error to provide credentials and a transport instance.
     transport = transports.AutoSuggestionServiceGrpcTransport(
@@ -927,6 +1189,7 @@ def test_transport_get_channel():
     [
         transports.AutoSuggestionServiceGrpcTransport,
         transports.AutoSuggestionServiceGrpcAsyncIOTransport,
+        transports.AutoSuggestionServiceRestTransport,
     ],
 )
 def test_transport_adc(transport_class):
@@ -941,6 +1204,7 @@ def test_transport_adc(transport_class):
     "transport_name",
     [
         "grpc",
+        "rest",
     ],
 )
 def test_transport_kind(transport_name):
@@ -1068,6 +1332,7 @@ def test_auto_suggestion_service_transport_auth_adc(transport_class):
     [
         transports.AutoSuggestionServiceGrpcTransport,
         transports.AutoSuggestionServiceGrpcAsyncIOTransport,
+        transports.AutoSuggestionServiceRestTransport,
     ],
 )
 def test_auto_suggestion_service_transport_auth_gdch_credentials(transport_class):
@@ -1169,11 +1434,23 @@ def test_auto_suggestion_service_grpc_transport_client_cert_source_for_mtls(
             )
 
 
+def test_auto_suggestion_service_http_transport_client_cert_source_for_mtls():
+    cred = ga_credentials.AnonymousCredentials()
+    with mock.patch(
+        "google.auth.transport.requests.AuthorizedSession.configure_mtls_channel"
+    ) as mock_configure_mtls_channel:
+        transports.AutoSuggestionServiceRestTransport(
+            credentials=cred, client_cert_source_for_mtls=client_cert_source_callback
+        )
+        mock_configure_mtls_channel.assert_called_once_with(client_cert_source_callback)
+
+
 @pytest.mark.parametrize(
     "transport_name",
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_auto_suggestion_service_host_no_port(transport_name):
@@ -1184,7 +1461,11 @@ def test_auto_suggestion_service_host_no_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("dataqna.googleapis.com:443")
+    assert client.transport._host == (
+        "dataqna.googleapis.com:443"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://dataqna.googleapis.com"
+    )
 
 
 @pytest.mark.parametrize(
@@ -1192,6 +1473,7 @@ def test_auto_suggestion_service_host_no_port(transport_name):
     [
         "grpc",
         "grpc_asyncio",
+        "rest",
     ],
 )
 def test_auto_suggestion_service_host_with_port(transport_name):
@@ -1202,7 +1484,33 @@ def test_auto_suggestion_service_host_with_port(transport_name):
         ),
         transport=transport_name,
     )
-    assert client.transport._host == ("dataqna.googleapis.com:8000")
+    assert client.transport._host == (
+        "dataqna.googleapis.com:8000"
+        if transport_name in ["grpc", "grpc_asyncio"]
+        else "https://dataqna.googleapis.com:8000"
+    )
+
+
+@pytest.mark.parametrize(
+    "transport_name",
+    [
+        "rest",
+    ],
+)
+def test_auto_suggestion_service_client_transport_session_collision(transport_name):
+    creds1 = ga_credentials.AnonymousCredentials()
+    creds2 = ga_credentials.AnonymousCredentials()
+    client1 = AutoSuggestionServiceClient(
+        credentials=creds1,
+        transport=transport_name,
+    )
+    client2 = AutoSuggestionServiceClient(
+        credentials=creds2,
+        transport=transport_name,
+    )
+    session1 = client1.transport.suggest_queries._session
+    session2 = client2.transport.suggest_queries._session
+    assert session1 != session2
 
 
 def test_auto_suggestion_service_grpc_transport_channel():
@@ -1473,6 +1781,7 @@ async def test_transport_close_async():
 
 def test_transport_close():
     transports = {
+        "rest": "_session",
         "grpc": "_grpc_channel",
     }
 
@@ -1490,6 +1799,7 @@ def test_transport_close():
 
 def test_client_ctx():
     transports = [
+        "rest",
         "grpc",
     ]
     for transport in transports:
